==> gimp-2.1.4.tar.bz2: gimp-2.1.4/app/actions/palette-editor-commands.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __PALETTE_EDITOR_COMMANDS_H__
#define __PALETTE_EDITOR_COMMANDS_H__


void   palette_editor_edit_color_cmd_callback   (GtkAction *action,
                                                 gpointer   data);
void   palette_editor_new_color_fg_cmd_callback (GtkAction *action,
                                                 gpointer   data);
void   palette_editor_new_color_bg_cmd_callback (GtkAction *action,
                                                 gpointer   data);
void   palette_editor_delete_color_cmd_callback (GtkAction *action,
                                                 gpointer   data);

void   palette_editor_zoom_in_cmd_callback      (GtkAction *action,
                                                 gpointer   data);
void   palette_editor_zoom_out_cmd_callback     (GtkAction *action,
                                                 gpointer   data);
void   palette_editor_zoom_all_cmd_callback     (GtkAction *action,
                                                 gpointer   data);


#endif /* __PALETTE_EDITOR_COMMANDS_H__ */

==> gimp-2.2.17.tar.bz2: gimp-2.2.17/app/actions/palette-editor-commands.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __PALETTE_EDITOR_COMMANDS_H__
#define __PALETTE_EDITOR_COMMANDS_H__


void   palette_editor_edit_color_cmd_callback   (GtkAction *action,
                                                 gpointer   data);
void   palette_editor_new_color_cmd_callback    (GtkAction *action,
                                                 gint       value,
                                                 gpointer   data);
void   palette_editor_delete_color_cmd_callback (GtkAction *action,
                                                 gpointer   data);

void   palette_editor_zoom_cmd_callback         (GtkAction *action,
                                                 gint       value,
                                                 gpointer   data);


#endif /* __PALETTE_EDITOR_COMMANDS_H__ */
